@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2002-2004 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 2002-2008 Erik de Castro Lopo <erikd@mega-nerd.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -16,6 +16,12 @@
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
 
+/*
+** This code is part of Secret Rabibt Code aka libsamplerate. A commercial
+** use license for this code is available, please see:
+**		http://www.mega-nerd.com/SRC/procedure.html
+*/
+
 #ifndef COMMON_H_INCLUDED
 #define COMMON_H_INCLUDED
 
@@ -33,8 +39,12 @@ typedef	long	int32_t ;
 #define	MAX(a,b)	(((a) > (b)) ? (a) : (b))
 #define	MIN(a,b)	(((a) < (b)) ? (a) : (b))
 
+#define	ARRAY_LEN(x)			((int) (sizeof (x) / sizeof ((x) [0])))
+#define OFFSETOF(type,member)	((int) (&((type*) 0)->member))
+
 #define	MAKE_MAGIC(a,b,c,d,e,f)	((a) + ((b) << 4) + ((c) << 8) + ((d) << 12) + ((e) << 16) + ((f) << 20))
 
+
 #include "samplerate.h"
 
 enum
@@ -67,6 +77,7 @@ enum
 	SRC_ERR_BAD_CALLBACK,
 	SRC_ERR_BAD_MODE,
 	SRC_ERR_NULL_CALLBACK,
+	SRC_ERR_NO_VARIABLE_RATIO,
 
 	/* This must be the last error number. */
 	SRC_ERR_MAX_ERROR
@@ -84,7 +95,13 @@ typedef struct SRC_PRIVATE_tag
 	/* Pointer to data to converter specific data. */
 	void	*private_data ;
 
-	int		(*process) (struct SRC_PRIVATE_tag *psrc, SRC_DATA *data) ;
+	/* Varispeed process function. */
+	int		(*vari_process) (struct SRC_PRIVATE_tag *psrc, SRC_DATA *data) ;
+
+	/* Constant speed process function. */
+	int		(*const_process) (struct SRC_PRIVATE_tag *psrc, SRC_DATA *data) ;
+
+	/* State reset. */
 	void	(*reset) (struct SRC_PRIVATE_tag *psrc) ;
 
 	/* Data specific to SRC_MODE_CALLBACK. */
@@ -112,13 +129,20 @@ const char* zoh_get_description (int src_enum) ;
 
 int zoh_set_converter (SRC_PRIVATE *psrc, int src_enum) ;
 
-#endif	/* COMMON_H_INCLUDED */
-
-/*
-** Do not edit or modify anything in this comment block.
-** The arch-tag line is a file identity tag for the GNU Arch 
-** revision control system.
-**
-** arch-tag: 737d46dc-a2f8-4025-bb88-fc8915c69085
+/*----------------------------------------------------------
+**	Common static inline functions.
 */
 
+static inline double
+fmod_one (double x)
+{	double res ;
+
+	res = x - lrint (x) ;
+	if (res < 0.0)
+		return res + 1.0 ;
+
+	return res ;
+} /* fmod_one */
+
+#endif	/* COMMON_H_INCLUDED */
+
